// THIS PROGRAM IS PROVIDED "AS IS". TI MAKES NO WARRANTIES OR
// REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
// INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
// FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
// COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
// TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
// POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
// INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
// YOUR USE OF THE PROGRAM.
//
// IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
// CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
// THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED 
// OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
// OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
// EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
// REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
// OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
// USE OR INTERRUPTION OF BUSINESS. IN NO EVENT WILL TI'S 
// AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF 
// YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS 
// (U.S.$500).
//
// Unless otherwise stated, the Program written and copyrighted 
// by Texas Instruments is distributed as "freeware".  You may, 
// only under TI's copyright in the Program, use and modify the 
// Program without any charge or restriction.  You may 
// distribute to third parties, provided that you transfer a 
// copy of this license to the third party and the third party 
// agrees to these terms by its first use of the Program. You 
// must reproduce the copyright notice and any other legend of 
// ownership on each copy or partial copy, of the Program.
//
// You acknowledge and agree that the Program contains 
// copyrighted material, trade secrets and other TI proprietary 
// information and is protected by copyright laws, 
// international copyright treaties, and trade secret laws, as 
// well as other intellectual property laws.  To protect TI's 
// rights in the Program, you agree not to decompile, reverse 
// engineer, disassemble or otherwise translate any object code 
// versions of the Program to a human-readable form.  You agree 
// that in no event will you alter, remove or destroy any 
// copyright notice included in the Program.  TI reserves all 
// rights not specifically granted under this license. Except 
// as specifically provided herein, nothing in this agreement 
// shall be construed as conferring by implication, estoppel, 
// or otherwise, upon you, any license or other right under any 
// TI patents, copyrights or trade secrets.
//
// You may not use the Program in non-TI devices.
//
/*****************************************************************************/
/*  MSP430FW427                                                              */
/*  Simple 1 Sensor Demo. A LED on P1.7 will show if the coil is above metal */
/*  (LED is off) or if the coild is not above metal (LED is on). On the LCD  */ 
/*  display the SIFCNT value is shown.                                       */
/*                                     Texas Instruments Deutschland GmbH    */
/*                                     November 2003, Christian Hernitscheck */
/*****************************************************************************/
#include "msp430xw42x.h"

/***  functions from file "LCD.s43" ***/
void InitScanIF(void);
void InitLCD(void);
void DisplayWord(unsigned int Data);

/***  Processing State Machine for a simple one sensor system ***/
const unsigned char PSM[] = {
                              0x00,     // State 0
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x03,     // State 3 - Counter is triggered
                              0x00,     // State 4
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x01,     // State 7
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used
                              0x00,     //*** not used    
                            };

unsigned int Counter;

/*---------------------------------------------------------------------------*/
void main(void)
{ 
  WDTCTL = WDTPW + WDTHOLD;         // disable Watchdog
  FLL_CTL0 |= XCAP10PF;             // Configure load caps
  InitLCD();
  InitScanIF();                     // initialization of ScanIf module

  P1OUT = 0x00;
  P1DIR = 0xFF;
  P2DIR = 0x7F;
  P3DIR = 0xFF;                     // termination of unused pins
  P4DIR = 0xFF;
  P5DIR = 0xFF;
  P6DIR = 0xFF;  

  Counter=0;
  DisplayWord(0x0000);

  _EINT();
  while(1)
  {
  if (SIFCTL3 & SIF0OUT)
    P1OUT |= 0x80;
  else
    P1OUT &= ~0x80;
  };
}

/*---------------------------------------------------------------------------*/
void InitScanIF(void)
{ int i;

  P6SEL |= 0x03;
  // Initialize Timing State Machine
  SIFTSM0 = 0x0000;   // DAC=off, CA=off, 1xSIFCLK
  SIFTSM1 = 0x002C;   // DAC=off, CA=off, 1xSIFCLK, excitation
  SIFTSM2 = 0x0404;   // DAC=off, CA=off, 1xACLK  
  SIFTSM3 = 0x0934;   // DAC=on,  CA=on,  2xSIFCLK, settling of DAC and Comparator
  SIFTSM4 = 0x3174;   // DAC=on,  CA=on,  7xSIFCLK, measurement
  SIFTSM5 = 0x0220;   // stop

  // Initialize DAC digital control values      
  SIFDACR0 = 0x0330;  // note that no hysteresis is used in this example!!!
  SIFDACR1 = 0x0330;
         
  // Initialize the Scan Interface Control Registers
  SIFCTL2 = 0x0140;  // DAC and Comparator are switched on by the TSM,
                     // switch on SIFVCCEx
  for (i=0;i<=857;i++); // wait loop. SIFVCCEx has to settle
  SIFCTL3 = 0x0100;  // SIF0OUT selected for S1 and S2 (S1 and S2 are input 
                     // signals of Processing State Machine)
                     // 4 COUNTS of SIFCNT1 for SIFIFG3      
  SIFCTL4 = 0x13F0;  // SIFCNT2 disabled, SIFCNT1 up Enabled, SIFCLK/450
  SIFCTL5 = 0x0045;  // SIFCLK is switched on by TSM, SIFCLK NOM Freq = 1MHz
  SIFPSMV = (unsigned int) &PSM;   // Offset address location of PSM
  SIFCTL1 |= 0x1001; // enable Scan Interface, enable interrupt SIFIFG3
}

/*---------------------------------------------------------------------------*/

#pragma vector=SCANIF_VECTOR
  __interrupt void ISR_ScanIF(void)
{
  SIFCTL1 &= ~0x0020;   // reset interrupt flag
  DisplayWord(SIFCNT);  // display the SIFCNT value
}
