#include "MSP430xw42x.h"

extern void DisplayCalib(void);
extern void DisplayWord(unsigned int Data);
extern void ClearDisplay(void);

const unsigned char PSMCalib[] = {
                              0x00,     // Init
                              0x00,     // Init
                              0x00,     // Init
                              0x00,     // Init
                            };

unsigned int WaitCounter;

unsigned int V1;
unsigned int V2;
unsigned int V3;
unsigned int V4;


void SIFCalib (void)
{int i;
  WDTCTL = WDT_ADLY_1000;
  _EINT();
  IE1 |= WDTIE;
  WaitCounter=5;
  DisplayWord(WaitCounter);
  while (WaitCounter>0);    // first wait 5 seconds (count-down)
  DisplayCalib();           // then begin calibration 
  WDTCTL = WDTPW + WDTHOLD;
  ClearDisplay();

  P6SEL |= 0x03;

  // Initialize Timing State Machine
  SIFTSM0 = 0x8800;   // DAC=off, CA=off, 31xSMCLK

  SIFTSM1 = 0x000C;   // DAC=off, CA=off,  1xSMCLK, excitation  SIFCH.0
  SIFTSM2 = 0x0404;   // DAC=off, CA=off,  1xACLK               SIFCH.0
  SIFTSM3 = 0x1914;   // DAC=on,  CA=on,   4x SMCLK             SIFCH.0
  SIFTSM4 = 0x4114;   // DAC=on,  CA=on,   9xSMCLK              SIFCH.0
  SIFTSM5 = 0x2154;   // DAC=on,  CA=on,   5xSMCLK    TEST      SIFCH.0

  SIFTSM6 = 0x000D;   // DAC=off, CA=off,  1xSMCLK, excitation  SIFCH.1
  SIFTSM7 = 0x0405;   // DAC=off, CA=off,  1xACLK               SIFCH.1
  SIFTSM8 = 0x1915;   // DAC=on,  CA=on,   4x SMCLK             SIFCH.1
  SIFTSM9 = 0x4115;   // DAC=on,  CA=on,   9xSMCLK              SIFCH.1
  SIFTSM10= 0x2155;   // DAC=on,  CA=on,   5xSMCLK    TEST      SIFCH.1

  SIFTSM11 = 0x0200;   // stop

  // Initialize DAC digital control values      
  SIFDACR0 = 0x03FF;  // SIFCH.0 - set to maximum value
  SIFDACR1 = 0x03FF;

  SIFDACR2 = 0x03FF;  // SIFCH.1 - set to maximum value
  SIFDACR3 = 0x03FF;
         
  // Initialize VSI Control Registers
  SIFCTL2 = 0x0140;  //   DAC and Comparator are controlled by SIFTSMx
  for (i=0;i<=857;i++); // wait loop. SIFVCCEx has to settle
  SIFCTL3 = 0x4000;  //   SIF0OUT selected for S1 and SIF1OUT selected for S2 
                     //   (S1 and S2 are input signals of Processing State Machine)
  SIFCTL4 = 0x0120;  //   SIFCNT settings
  SIFCTL5 = 0x0047;  //   SIFCLK is permanently switched on, SIFCLK=1MHz
  SIFPSMV = (unsigned int) &PSMCalib; // Signal Processing State Machine definition
  SIFCTL1 |= 0x0001; //   SIF_EN=1

//*********  Sensor 1 *************************
  while (!(SIFCTL3 & 0x01))  // Test 1
  {  
    for(i=0;i<=100;i++);
    SIFDACR0=SIFDACR0-1;
    SIFDACR1=SIFDACR1-1;
  }
  V1 = SIFDACR1;

  SIFDACR0 = 0x200;
  SIFDACR1 = 0x200;

  while (SIFCTL3&0x01)       // Test 2
  {
    for(i=0;i<=100;i++);
    SIFDACR0=SIFDACR0+1;
    SIFDACR1=SIFDACR1+1;
  }
  V2 = SIFDACR1;


  SIFDACR0 = (V2 + V1) / 2;  // Calculation of average value
  SIFDACR1 = SIFDACR0;

  SIFDACR0 = SIFDACR0 + 30;
  SIFDACR1 = SIFDACR1 - 30;
  
//*********  Sensor 2 *************************
  while (!(SIFCTL3 & 0x02))  // Test 1
  {  
    for(i=0;i<=100;i++);
    SIFDACR2=SIFDACR2-1;
    SIFDACR3=SIFDACR3-1;
  }
  V1 = SIFDACR2;

  SIFDACR2 = 0x200;
  SIFDACR3 = 0x200;

  while (SIFCTL3&0x02)       // Test 2
  {
    for(i=0;i<=100;i++);
    SIFDACR2=SIFDACR2+1;
    SIFDACR3=SIFDACR3+1;
  }
  V2 = SIFDACR3;


  SIFDACR2 = (V2 + V1) / 2;  // Calculation of average value
  SIFDACR3 = SIFDACR2;
  
  SIFDACR2 = SIFDACR2 + 30;
  SIFDACR3 = SIFDACR3 - 30;

//********* E N D ****************
 
}



#pragma vector=WDT_VECTOR
  __interrupt void ISR_WDT(void)
{
  WaitCounter = WaitCounter - 1;  // Count-down before calibration
  DisplayWord(WaitCounter);
}
