// THIS PROGRAM IS PROVIDED "AS IS". TI MAKES NO WARRANTIES OR
// REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
// INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
// FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
// COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
// TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
// POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
// INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
// YOUR USE OF THE PROGRAM.
//
// IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
// CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
// THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED 
// OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
// OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
// EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
// REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
// OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
// USE OR INTERRUPTION OF BUSINESS. IN NO EVENT WILL TI'S 
// AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF 
// YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS 
// (U.S.$500).
//
// Unless otherwise stated, the Program written and copyrighted 
// by Texas Instruments is distributed as "freeware".  You may, 
// only under TI's copyright in the Program, use and modify the 
// Program without any charge or restriction.  You may 
// distribute to third parties, provided that you transfer a 
// copy of this license to the third party and the third party 
// agrees to these terms by its first use of the Program. You 
// must reproduce the copyright notice and any other legend of 
// ownership on each copy or partial copy, of the Program.
//
// You acknowledge and agree that the Program contains 
// copyrighted material, trade secrets and other TI proprietary 
// information and is protected by copyright laws, 
// international copyright treaties, and trade secret laws, as 
// well as other intellectual property laws.  To protect TI's 
// rights in the Program, you agree not to decompile, reverse 
// engineer, disassemble or otherwise translate any object code 
// versions of the Program to a human-readable form.  You agree 
// that in no event will you alter, remove or destroy any 
// copyright notice included in the Program.  TI reserves all 
// rights not specifically granted under this license. Except 
// as specifically provided herein, nothing in this agreement 
// shall be construed as conferring by implication, estoppel, 
// or otherwise, upon you, any license or other right under any 
// TI patents, copyrights or trade secrets.
//
// You may not use the Program in non-TI devices.
//
/*****************************************************************************/
/*  MSP430FW427                                                October 2003  */
/*  2 LC-Sensors system. There are two differne PSM state machines defined.  */
/*  By defining the string "PSM_Version_UG" the User's Guide version will be */
/*  used for the PSM state machine. If the string "PSM_Version_Advanced" is  */
/*  defined the advanced PSM state machine is used. (just comment out the    */
/*  not used one).                                                           */
/*****************************************************************************/
#include "msp430xw42x.h"

//#define PSM_Version_UG       // PSM state machine from the User's Guide is used.
#define PSM_Version_Advanced // advanced PSM state machine is used.

#define __msp430xW42x
/***  Calibration.c  ***/
extern void InitScanIF(void);

/***  LCD.s43  ***/
extern void InitLCD(void);
extern void DisplayWord(unsigned int Data);
extern void SIFCalib(void);
extern void DisplayByte(unsigned int Data);


#ifdef PSM_Version_UG
/***  Processing State Machine of the Scan Interface module description  ***/
const unsigned char PSM[] = {
                              0x00,  // no rotation
                              0x03,  // turns right (+1)
                              0x0C,  // turns left  (-1)
                              0x49,  // error
                              0x00,  // turns left
                              0x01,  // no rotation
                              0x48,  // error
                              0x09,  // turns right
                              0x00,  // turns right
                              0x41,  // error
                              0x08,  // no rotation
                              0x09,  // turns left
                              0x40,  // error 
                              0x01,  // turns left
                              0x08,  // turns right
                              0x09   // no rotation
                            };
#endif

#ifdef PSM_Version_Advanced
/*** Processing State Machine (advanced version) ***/
const unsigned char PSM[] = {
                              0x00,  // state 0
                              0x13,  // state 1
                              0x0C,  // state 2
                              0x4D,  // state 3
                              0x04,  // state 4
                              0x01,  // state 5
                              0x4C,  // state 6
                              0x5B,  // state 7
                              0x52,  // state 8
                              0x45,  // state 9
                              0x08,  // state 10
                              0x0D,  // state 11
                              0x44,  // state 12
                              0x05,  // state 13
                              0x5A,  // state 14
                              0x09,  // state 15
                              0x10,  // state 16
                              0x13,  // state 17
                              0x4C,  // state 18
                              0x5B,  // state 19
                              0x44,  // state 20
                              0x11,  // state 21
                              0x5A,  // state 22
                              0x1B,  // state 23
                              0x12,  // state 24
                              0x53,  // state 25
                              0x18,  // state 26
                              0x4D,  // state 27
                              0x52,  // state 28
                              0x45,  // state 29
                              0x1A,  // state 30
                              0x19   // state 31
                            };
#endif     
                            
/*---------------------------------------------------------------------------*/
void main(void)
{ 
  WDTCTL = WDTPW + WDTHOLD;         // disable Watchdog
  FLL_CTL0 |= XCAP10PF;             // Configure load caps

  InitLCD();

  P1OUT = 0x00;
  P1DIR = 0xFF;
  P2DIR = 0x7F;
  P3DIR = 0xFF;                     // termination of unused pins
  P4DIR = 0xFF;
  P5DIR = 0xFF;
  P6DIR = 0xFF;
  
  P2SEL |= 0x80;   // P2.7 => SIFCLKG
  
  SIFCalib();                       // Calibration of DAC thresholds
  InitScanIF();                     // initialization of ScanIf module
  DisplayByte(0x0000);

  _EINT();
  LPM3;               // **** comment out this line to allow to show on 
                      //      P1.7 and P1.6 via LEDs if the sensors are 
                      //      damped of un-damped
  while (1)
  {
    if (SIFCTL3 & 0x01)    // SIF0OUT is tested
      P1OUT |= 0x80;       //      if SIF0OUT=1 then a LED (P1.7) is switched on
    else
      P1OUT &= ~0x80;      //      otherwise the LED is switched off
    
    if (SIFCTL3 & 0x02)    // SIF1OUT is tested
      P1OUT |= 0x40;       //      if SIF1OUT=1 then a LED (P1.6) is swiched on
    else
      P1OUT &= ~0x40;      //      otherwise the LED is switched off
  
  }
}

/*---------------------------------------------------------------------------*/
void InitScanIF(void)
{ int i;

  P6SEL |= 0x03;

  // Initialize Timing State Machine
  SIFTSM0 = 0x8800;   // DAC=off, CA=off, 31xSMCLK    (delay for proper timing for both LC sensors)

  SIFTSM1 = 0x002C;   // DAC=off, CA=off,  1xSIFCLK, excitation  SIFCH.0
  SIFTSM2 = 0x0424;   // DAC=off, CA=off,  1xACLK                SIFCH.0
  SIFTSM3 = 0x1934;   // DAC=on,  CA=on,   4xSIFCLK              SIFCH.0
  SIFTSM4 = 0x4134;   // DAC=on,  CA=on,  14xSIFCLK              SIFCH.0
  SIFTSM5 = 0x2174;   // DAC=on,  CA=on,  14xSIFCLK              SIFCH.0
  
  SIFTSM6 = 0x002D;   // DAC=off, CA=off,  1xSIFCLK, excitation  SIFCH.1
  SIFTSM7 = 0x0425;   // DAC=off, CA=off,  1xACLK                SIFCH.1
  SIFTSM8 = 0x1935;   // DAC=on,  CA=on,   4xSIFCLK              SIFCH.1
  SIFTSM9 = 0x4135;   // DAC=on,  CA=on,  14xSIFCLK              SIFCH.1
  SIFTSM10 = 0x2175;  // DAC=on,  CA=on,  14xSIFCLK              SIFCH.1

  SIFTSM11 = 0x0220;   // stop

  // Initialize Scan Interface Control Registers
  SIFCTL2 = 0x0140;  // DAC and comparator are controlled by SIFTSMx
  for (i=0;i<=857;i++); // wait loop. SIFVCCEx has to settle
  SIFCTL3 = 0x4000;  // SIF0OUT selected for S1, SIF1OUT selected for S2 
                     // (S1 and S2 are input signals of Processing State Machine)
  SIFCTL4 = 0x33F0;  // initialize PSM counters
  SIFCTL5 = 0x0045;  // SIFCLK is controlled by SIFTSMx
                     // SIFCLK = 1MHz
  SIFPSMV = (unsigned int) &PSM; // Definition of PSM vector
  SIFCTL1 |= 0x1001; // switch on Scan Interface. enable interrupt
}

/*---------------------------------------------------------------------------*/

#pragma vector=SCANIF_VECTOR
  __interrupt void ISR_ScanIF(void)
{
  DisplayByte(SIFCNT);
  SIFCTL1 &= ~0x0060;     
}

 

